pub struct InfoFile {
pub length: usize,
pub path: Vec<String>,
pub md5sum: Option<String>,
}Fields
length: usizeThe length of the file, in bytes.
path: Vec<String>Subdirectory names for this file, the last of which is the actual file name (a zero length list is an error case).
md5sum: Option<String>A 32-character hex string corresponding to the MD5 sum of the file. Not used by BitTorrent at all, but included by some programs for greater compatablility.