pub enum Tracker {
Http(String),
Udp(String),
Websocket(String),
}Expand description
An Announce URI from a torrent file or magnet URI. HTTP trackers: https://www.bittorrent.org/beps/bep_0003.html UDP trackers: https://www.bittorrent.org/beps/bep_0015.html
Example tracker: udp://tracker.opentrackr.org:1337/announce
Example usage:
let tracker = Tracker::Http("udp://tracker.opentrackr.org:1337/announce");
let server = UdpServer::new();
let tracker = tracker.to_instance(info_hash, peer_id, port, Some(server));
tracker.initialize().await;
let peers: Vec<Peer> = tracker.announce();Variants
Implementations
Sourceimpl Tracker
impl Tracker
Sourcepub async fn to_base(
&self,
info_hash: InfoHash,
peer_id: PeerId,
port: u16,
server: UdpServer,
) -> Result<Box<dyn TrackerBase>>
👎Deprecated: Use to_instance instead
pub async fn to_base( &self, info_hash: InfoHash, peer_id: PeerId, port: u16, server: UdpServer, ) -> Result<Box<dyn TrackerBase>>
to_instance insteadCreates a new tracker instance based on the tracker type.
Sourcepub async fn to_instance(
&self,
info_hash: InfoHash,
peer_id: PeerId,
port: u16,
server: UdpServer,
) -> Result<TrackerInstance>
pub async fn to_instance( &self, info_hash: InfoHash, peer_id: PeerId, port: u16, server: UdpServer, ) -> Result<TrackerInstance>
Creates an instance of the Tracker struct from an info hash,
a peer ID, a port,
pub fn uri(&self) -> String