pub struct TrackerStats { /* private fields */ }Expand description
Tracker statistics
All usages of AtomicOptionInstant or AtomicInstant are a bit hacky, due to the fact that they only support Instant from std, not tokio. See any of the getter/setter methods as an example.
Implementations
Sourceimpl TrackerStats
impl TrackerStats
pub fn get_announce_attempts(&self) -> usize
pub fn increment_announce_attempts(&self)
pub fn get_announce_successes(&self) -> usize
pub fn increment_announce_successes(&self)
pub fn get_total_peers_received(&self) -> usize
pub fn increment_total_peers_received(&self, value: usize)
pub fn get_bytes_sent(&self) -> usize
pub fn increment_bytes_sent(&self, value: usize)
pub fn get_bytes_received(&self) -> usize
pub fn increment_bytes_received(&self, value: usize)
pub fn get_last_interaction(&self) -> Option<Instant>
pub fn set_last_interaction(&self)
pub fn get_session_start(&self) -> Instant
pub fn set_session_start(&self)